/**
  ******************************************************************************
  * @file    stm8l1526_eval_glass_lcd.h
  * @author  MCD Application Team
  * @version V0.0.3
  * @date    07/21/2009
  * @brief   This file contains all the functions prototypes for the glass LCD
  *          firmware driver.
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2009 STMicroelectronics</center></h2>
  */ 

// Define to prevent recursive inclusion -------------------------------------
#ifndef __STM8L1526_GLASS_LCD_H
#define __STM8L1526_GLASS_LCD_H

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"

//#define USE_LSE

// Private define ------------------------------------------------------------
typedef enum
{
  POINT_OFF = 0,
  POINT_ON = 1
}Point_Typedef;

typedef enum
{
  COLUMN_OFF = 0,
  COLUMN_ON = 1
}Column_Typedef;


#define LCD_CLEAR_BYTE (uint8_t)0x00;
#define LCD_SET_BYTE   (uint8_t)0xFF;
#define LCD_CLEAR_MSB  (uint8_t)0x0F;
#define LCD_CLEAR_LSB  (uint8_t)0xF0;

// Exported constants --------------------------------------------------------
// Exported macro ------------------------------------------------------------
// Exported functions ------------------------------------------------------- 

void LCD_GLASS_Init(void);
void LCD_Test(void);
void LCD_GLASS_WriteChar(uint8_t* ch, Point_Typedef point, 
                         Column_Typedef column,uint8_t position);
void LCD_GLASS_DisplayString(uint8_t* ptr);
void LCD_GLASS_ClearChar(uint8_t position);
void LCD_GLASS_Clear(void);
void LCD_GLASS_ScrollSentence(uint8_t* ptr, uint8_t ptr_size, uint16_t nScroll, uint16_t ScrollSpeed);
void LCD_GLASS_WriteTime(char a, uint8_t posi, Column_Typedef column);

#endif /* __STM8L1526_EVAL_GLASS_LCD_H*/

