
// Includes ------------------------------------------------------------------
#include "LPdemo_functions.h"
#include "stm8l1526_glass_lcd.h"

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------

#define OA_OFFSET 200;

extern bool mode_bool[NB_MODE];
extern bool IDD_bool;
extern bool RTC_bool;
extern bool Wakeup_bool;
extern bool Function_bool;
extern bool KeyPressed;
extern char a,b,c,d;
extern u16 Vrefint;
extern float Vdd;
extern bool TEST_bool;
extern bool TEST_PASS ;

bool LPWait_bool = FALSE;
bool Battery_bool = TRUE;




// This function converts a number into char 
void convert_into_char(int number, uint8_t *p_tab)
{
	int units=0, tens=0, hundreds=0, thousands=0, misc=0;
	units = (((number%10000)%1000)%100)%10;
	tens = ((((number-units)/10)%1000)%100)%10;
	hundreds = (((number-tens-units)/100))%100%10;
	thousands = ((number-hundreds-tens-units)/1000)%10;
	misc = ((number-thousands-hundreds-tens-units)/10000);
 
	*(p_tab) =(uint8_t)(units + 0x30);
	*(p_tab+1)=(uint8_t)(tens + 0x30);
	*(p_tab+2)=(uint8_t)(hundreds + 0x30);
	*(p_tab+3)=(uint8_t)(thousands + 0x30);
	*(p_tab+4)=(uint8_t)(misc + 0x30);
	return;
}

// Function in RAM (used in Low Power Run and Wait modes 

#pragma section (LPRUN)

void	LPR_Ram(void)
{ 
	int i = 0;
	// Swith off the Flash
  FLASH->CR1 = 0x08;
	while(((CLK->REGCSR)&0x80)==0x80);
	// Swith off the Regulator
	CLK->REGCSR = 0x02;
  while(((CLK->REGCSR)&0x01)==0x01);
	// test if Low Power Wait mode 
  switch (LPWait_bool)
	{
		case FALSE: // Low Power Run mode
		{
			do
			{	
				if (IDD_bool == TRUE)
				{
					WFE->CR1 = 0xF0;
          
					for (i=0; i<100; i++);
				  // Activate CNT EN PIN as output push-pull, active low
	
					
					GPIOA->ODR = 0xFB;
				}
				else	
				{
					while ((((EXTI->SR1)& 0x01)==0x00) && (((EXTI->SR1)& 0x02)==0x00)); 
					if (((EXTI->SR1)& 0x01)==0x01) // FUNCTION is pressed
					{
						//enable LCD
						EXTI->SR1 = 0x01;
						CLK->PCKENR2 = 0x0C;
						LCD->CR3 = 0x40;
					}		
				}
			}
			while ((((EXTI->SR1)& 0x02)==0x00) && ((EXTI->SR1)& 0x08)==0x00); //Exit LPR when WAKEUP is pressed 
		}	

		case TRUE: //Low Power Wait Mode
		{
			if (IDD_bool == TRUE)
				{
					WFE->CR1 = 0xF0;
		
					for (i=0; i<100; i++);
				  // Activate CNT EN PIN as output push-pull, active low

					GPIOA->ODR = 0xFB;
					wfe();
				}
			else
			{
				while(((EXTI->SR1)& 0x02)==0x0) //Exit LPR when WAKEUP is pressed
				{
					wfe();	
					if (((EXTI->SR1)& 0x01)==0x01) //FUNCTION is pressed
					{
						//enable LCD
						EXTI->SR1 = 0x01;
						CLK->PCKENR2 = 0x0C;
						LCD->CR3 = 0x40;
						wfe();				
					}
				}
			}
		}	
	}
	EXTI->SR1 = 0x0A;
	//Switch on the regulator
	CLK->REGCSR = 0x00;
	while(((CLK->REGCSR)&0x1) != 0x1);		
}
#pragma section ()

// Function to initialize the entry in Low Power Run and Wait modes 
void LPR_init(void)
{
	int i =0;
	//Switch the clock to LSE and disable HSI
	#ifdef USE_LSE
		CLK_SYSCLKSourceConfig(CLK_SYSCLKSource_LSE);	
		CLK_SYSCLKSourceSwitchCmd(ENABLE);
		while (((CLK->SWCR)& 0x01)==0x01);
		CLK_HSICmd(DISABLE);
	#else
		CLK_SYSCLKSourceConfig(CLK_SYSCLKSource_LSI);
		CLK_SYSCLKSourceSwitchCmd(ENABLE);
		while (((CLK->SWCR)& 0x01)==0x01);
		CLK_HSICmd(DISABLE);
	#endif

	//Configure event for WAKEUP and FUNCTION, disable the interrupts
	WFE->CR1 = 0x30;
	sim();
		
  if (!(_fctcpy('L')))
	  while(1);
		
	LPR_Ram(); // Jump in RAM

	//Switch the clock to HSI
	CLK_HSICmd(ENABLE);
	while (((CLK->ICKCR)& 0x02)!=0x02);
	CLK_SYSCLKSourceConfig(CLK_SYSCLKSource_HSI);
	CLK_SYSCLKSourceSwitchCmd(ENABLE);
	while (((CLK->SWCR)& 0x01)==0x01);
	
}

/* This function initializes in Ultra Low Power mode, 
disable the LCD, LSE and configures the unused IOs 
in output push-pull */

void Halt_Init(void)
{
	//PWR->CSR2 = 0x2;

	LCD_Cmd(DISABLE);
	while ((LCD->CR3 & 0x40) != 0x00);
	GPIO_LowPower_Config(MCU_HALT);
	CLK_RTCClockConfig(CLK_RTCCLKSource_Off, CLK_RTCCLKDiv_1);
	#ifdef USE_LSE
		CLK_LSEConfig(CLK_LSE_OFF);
		while ((CLK->ECKCR & 0x04) != 0x00);
	#else
		CLK_LSICmd(DISABLE);
		while ((CLK->ICKCR & 0x04) != 0x00);
	#endif

	
	CLK_PeripheralClockConfig(CLK_Peripheral_RTC, DISABLE);
	CLK_PeripheralClockConfig(CLK_Peripheral_LCD, DISABLE);
}

// This function asks for automatic measurement 
void IDD_question(void)
{
	LCD_GLASS_DisplayString("  AUTO");
	//while(KeyPressed == FALSE);
	halt();
	KeyPressed = FALSE;
	if (Wakeup_bool == TRUE) //Auto IDD mode disable
	{
			IDD_bool = FALSE;
			Wakeup_bool = FALSE;
			Function_bool = FALSE;

	}
	else // Auto IDD mode enable
	{
			IDD_bool = TRUE;
			Wakeup_bool = FALSE;
			Function_bool = FALSE;
	}
}
// This function asks for RTC initialization 
void RTC_question(void)
{
	LCD_GLASS_DisplayString("  RTC ");
	//while(KeyPressed == FALSE);
	halt();
	KeyPressed = FALSE;
	if (Wakeup_bool == TRUE) //RTC Init disable
	{
			RTC_bool = FALSE;
			Wakeup_bool = FALSE;
			Function_bool = FALSE;
	}
	else // RTC Init enable
	{
			RTC_bool = TRUE;
			Wakeup_bool = FALSE;
			Function_bool = FALSE;
	}
}

// This function enables the RTC interrupt every second 
void RTC_secItEn()
{
	RTC->WPR = 0xCA;
	RTC->WPR = 0x53;
	RTC->ALRMAR1 = 0x80;
	RTC->ALRMAR2 = 0x80;
	RTC->ALRMAR3 = 0x80;
	RTC->ALRMAR4 = 0x80;

	RTC->CR2 = 0x11;	
}


/* This function initializes the RTC for seconds, minutes,
hours */
void RTC_InitTime(int sec, int min, int hour)
{ 
	int units=0, tens=0;


	RTC->WPR = 0xCA;
	RTC->WPR = 0x53;

	RTC->ISR1 = 0x80;
	RTC->ISR2 = 0x0;
	while ((RTC->ISR1 & 0x40) != 0x40);
	units = sec%10;
	tens = (sec - units)/10;
	RTC->TR1 = (tens<<4) | units;
	units = min%10;
	tens = (min - units)/10;
	RTC->TR2 = (tens<<4) | units;
	units = hour%10;
	tens = (hour - units)/10;
	RTC->TR3 = (tens<<4) | units;
	RTC->ISR1 = 0x0;
  RTC_secItEn();
}

/* This function asks for RTC values for seconds, minutes,
hours */
void RTC_doInit(void)
{
	int sec = 0, min = 0, hour = 0;
	uint8_t tab[6];
	int units=0, tens=0;
	int count = 0;

	
	LCD_GLASS_DisplayString("  SEC  ");
	do 
	{
		halt();
		KeyPressed == FALSE;
		if (Function_bool == TRUE)
		{
			Function_bool = FALSE;
			
			units = sec%10;
			tens = (sec - units)/10;
			tab[0]=(uint8_t)(units + 0x30);
			tab[1]=(uint8_t)(tens + 0x30);
			LCD_GLASS_WriteChar( tab,POINT_OFF,COLUMN_OFF,7);
			LCD_GLASS_WriteChar( tab+1,POINT_OFF,COLUMN_ON,6);
			LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,5);
			LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_ON,4);
			LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,3);
			LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,2);
			LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,1);
			if (sec < 60)
				sec = sec + 1;
			else 
				sec = 0;

		}
	}
	while (Wakeup_bool == FALSE);
	Wakeup_bool = FALSE;

	LCD_GLASS_DisplayString("  MIN   ");
	do 
	{
		halt();
		KeyPressed == FALSE;
		if (Function_bool == TRUE)
		{
			Function_bool = FALSE;
			
		
			units = min%10;
			tens = (min - units)/10;
			tab[2]=(uint8_t)(units + 0x30);
			tab[3]=(uint8_t)(tens + 0x30);
			LCD_GLASS_WriteChar( tab,POINT_OFF,COLUMN_OFF,7);
			LCD_GLASS_WriteChar( tab+1,POINT_OFF,COLUMN_ON,6);
			LCD_GLASS_WriteChar( tab+2,POINT_OFF,COLUMN_OFF,5);
			LCD_GLASS_WriteChar( tab+3,POINT_OFF,COLUMN_ON,4);
			LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,3);
			LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,2);
			LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,1);
			
			if (min < 60)
			  min = min + 1;
			else
				min = 0;

			//LCD_GLASS_DisplayString(tab);
		}
	}
	while (Wakeup_bool == FALSE);
	Wakeup_bool = FALSE;

	LCD_GLASS_DisplayString("  HOUR   ");
	do 
	{
		halt();;
		KeyPressed == FALSE;
		if (Function_bool == TRUE)
		{
			Function_bool = FALSE;

		
			units = hour%10;
			tens = (hour - units)/10;
			tab[4]=(uint8_t)(units + 0x30);
			tab[5]=(uint8_t)(tens + 0x30);
			LCD_GLASS_WriteChar( tab,POINT_OFF,COLUMN_OFF,7);
			LCD_GLASS_WriteChar( tab+1,POINT_OFF,COLUMN_ON,6);
			LCD_GLASS_WriteChar( tab+2,POINT_OFF,COLUMN_OFF,5);
			LCD_GLASS_WriteChar( tab+3,POINT_OFF,COLUMN_ON,4);
			LCD_GLASS_WriteChar( tab+4,POINT_OFF,COLUMN_OFF,3);
			LCD_GLASS_WriteChar( tab+5,POINT_OFF,COLUMN_OFF,2);
			LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,1);
			
			if (hour < 24)
			  hour = hour + 1;
			else
				hour = 0;

		}
	}
	while (Wakeup_bool == FALSE);
	Wakeup_bool = FALSE;
	
	if (sec != 0) sec = sec - 1;
	else sec = 59;
	if (min != 0) min = min - 1;
	else min = 59;
	if (hour != 0) hour = hour - 1;
	else hour = 23;	
	
	RTC_InitTime(sec, min, hour);
	a = RTC->TR1;
	b = RTC->TR2;
	c = RTC->TR3;
	d = RTC->DR3;
	count = 5;
	while (count != 0)
	{
		LCD_GLASS_WriteTime( a & 0xF     , 7, 0);
		LCD_GLASS_WriteTime((a & 0xF0)>>4, 6, 1);
		LCD_GLASS_WriteTime( b & 0xF     , 5, 0);
		LCD_GLASS_WriteTime((b & 0xF0)>>4, 4, 1);
		LCD_GLASS_WriteTime( c & 0xF     , 3, 0);
		LCD_GLASS_WriteTime((c & 0xF0)>>4, 2, 0);
		count = count-1;
		halt();
  }
	RTC->CR2 = 0x0;
	
}

// This function dispays "CHOOSE MODE" 
void LPMode_Init(void)
{
	int i = 0;

	//LCD_GLASS_ScrollSentence("CHOOSE MODE  ", 13, 0, SCROLL_SPEED);
	for (i = 0; i < NB_MODE; i++) mode_bool[i] = FALSE;
}

/* This function asks for each mode
If Wakeup is pressed the mode is not chosen
If Function is pressed the mode is chosen
*/
void mode_question(int mode)
{
	switch (mode)
	{
		case 1: LCD_GLASS_DisplayString(" MODE1 ");break;
		case 2: LCD_GLASS_DisplayString(" MODE2 ");break;
		case 3: LCD_GLASS_DisplayString(" MODE3 ");break;
		case 4: LCD_GLASS_DisplayString(" MODE4 ");break;
		case 5: LCD_GLASS_DisplayString(" MODE5 ");break;
		case 6: LCD_GLASS_DisplayString(" MODE6 ");break;
		case 7: LCD_GLASS_DisplayString(" MODE7 ");break;
		default: LCD_GLASS_DisplayString(" ERROR ");
  }
	//while(KeyPressed == FALSE);
	halt();
	KeyPressed = FALSE;
	if (Wakeup_bool == TRUE) //Mode  disable
	{
		switch (mode)
		{
			case 1: mode_bool[1] = FALSE;break;
			case 2: mode_bool[2] = FALSE;break;
			case 3: mode_bool[3] = FALSE;break;
			case 4: mode_bool[4] = FALSE;break;
			case 5: mode_bool[5] = FALSE;break;
			case 6: mode_bool[6] = FALSE;break;
			case 7: mode_bool[7] = FALSE;break;
		}
			Wakeup_bool = FALSE;
			Function_bool = FALSE;
	}
	else // Mode  enable
	{
		switch (mode)
		{
			case 1: mode_bool[1] = TRUE;break;
			case 2: mode_bool[2] = TRUE;break;
			case 3: mode_bool[3] = TRUE;break;
			case 4: mode_bool[4] = TRUE;break;
			case 5: mode_bool[5] = TRUE;break;
			case 6: mode_bool[6] = TRUE;break;
			case 7: mode_bool[7] = TRUE;break;
		}
			Wakeup_bool = FALSE;
			Function_bool = FALSE;
	}
}
// This function enters the selected mode 
void launch_mode(int mode)
{
	switch (mode)
		{
			case 1: mode1();break;
			case 2: mode2();break;
			case 3: mode3();break;
			case 4: mode4();break;
			case 5: mode5();break;
			case 6: mode6();break;
			case 7: mode7();break;
		}
}

// Mode 1 : RUN mode at 16MHz 
void mode1(void)
{
	int Vdd_mV = 0;
	int units=0, tens=0, hundreds=0, thousands=0;
  uint8_t tab[4];
	float Run_Conso=0;
	int Run_Conso_uA=0;
	int i = 0;
	int ADC_ConvResult;
	extern bool initmode_bool;
	
	Wakeup_bool = FALSE;
	Function_bool = FALSE;

	
	if (initmode_bool == TRUE)
	{
		LCD_GLASS_Clear();
		LCD_GLASS_DisplayString(" RUN16 ");
		for (i = 0; i < 3; i++) Delay(60000);
		LCD_GLASS_Clear();
		LCD_GLASS_ScrollSentence("BATTERY            ", 8, SCROLL_NUM, SCROLL_SPEED);
		initmode_bool = FALSE;
	}
	

	if ((Battery_bool == TRUE ) || (initmode_bool == TRUE)) 
	{
	
		Vrefint = ADC_Supply();
		Vdd = 4095*1.23/Vrefint;
		Vdd_mV = Vdd*1000;
	  
		convert_into_char(Vdd_mV, tab);
	
		LCD_GLASS_Clear();
		LCD_GLASS_WriteChar( "V",POINT_OFF,COLUMN_OFF,7);
		LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,6);
		LCD_GLASS_WriteChar( tab+1,POINT_OFF,COLUMN_OFF,5);
		LCD_GLASS_WriteChar( tab+2,POINT_OFF,COLUMN_OFF,4);
		LCD_GLASS_WriteChar( tab+3,POINT_ON,COLUMN_OFF,3);
	}
	else
	{
		a = RTC->TR1;
    b = RTC->TR2;
		c = RTC->TR3;
		d = RTC->DR3;
		RTC_secItEn();
		while (KeyPressed == FALSE)
		{
			LCD_GLASS_WriteTime( a & 0xF     , 7, COLUMN_OFF);
			LCD_GLASS_WriteTime((a & 0xF0)>>4, 6, COLUMN_ON);
			LCD_GLASS_WriteTime( b & 0xF     , 5, COLUMN_OFF);
			LCD_GLASS_WriteTime((b & 0xF0)>>4, 4, COLUMN_ON);
			LCD_GLASS_WriteTime( c & 0xF     , 3, COLUMN_OFF);
			LCD_GLASS_WriteTime((c & 0xF0)>>4, 2, COLUMN_OFF);
		}
		RTC->CR2 = 0x0;
	}

	if (IDD_bool == TRUE) 
	{
	  while (Function_bool == FALSE);
		Function_bool = FALSE;
		delay_10us(1);
		ADC_ConvResult = ADC_Icc_Test(MCU_RUN);
		Run_Conso =  (ADC_ConvResult * Vdd) *10 / 4.095 ;
		Run_Conso_uA = (int)(Run_Conso);
	
		convert_into_char(Run_Conso_uA, tab);
		
		LCD_GLASS_Clear();
		LCD_GLASS_WriteChar( "A",POINT_OFF,COLUMN_OFF,7);
		LCD_GLASS_WriteChar( "m",POINT_OFF,COLUMN_OFF,6);
		LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,5);
		LCD_GLASS_WriteChar( tab+1,POINT_OFF,COLUMN_OFF,4);
		LCD_GLASS_WriteChar( tab+2,POINT_OFF,COLUMN_OFF,3);
		LCD_GLASS_WriteChar( tab+3,POINT_ON,COLUMN_OFF,2);
		CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_16);
		while (Wakeup_bool == FALSE);
	}
	else
	{
		while ((Function_bool == FALSE) && (Wakeup_bool == FALSE));
		{
			Function_bool = FALSE;
			KeyPressed = FALSE;
			Battery_bool = FALSE;
		}
	}
}
// Mode 2 : WAIT mode at 16MHz 
void mode2(void)
{
	int units=0, tens=0, hundreds=0, thousands=0;
  uint8_t tab[4];
	float Run_Conso=0;
	int Run_Conso_uA=0;
	int i = 0;
	int ADC_ConvResult;
	
	Wakeup_bool = FALSE;
	Function_bool = FALSE;
		
	LCD_GLASS_Clear();
	LCD_GLASS_DisplayString("WAIT16");
	
	FLASH->CR1 = 0x04;
		
		if (IDD_bool == TRUE) 
		{
			Vrefint = ADC_Supply();
			Vdd = 4095*1.23/Vrefint;
			WFE->CR1 = 0x30;
			wfe();
			EXTI->SR1 = 0x03;
			
			ADC_ConvResult = ADC_Icc_Test(MCU_RUN);
			Run_Conso =  (ADC_ConvResult * Vdd) *10 / 4.095 ;
			Run_Conso_uA = (int)(Run_Conso);
	
			convert_into_char(Run_Conso_uA, tab);
		
			LCD_GLASS_Clear();
			LCD_GLASS_WriteChar( "A",POINT_OFF,COLUMN_OFF,7);
			LCD_GLASS_WriteChar( "m",POINT_OFF,COLUMN_OFF,6);
			LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,5);
			LCD_GLASS_WriteChar( tab+1,POINT_OFF,COLUMN_OFF,4);
			LCD_GLASS_WriteChar( tab+2,POINT_OFF,COLUMN_OFF,3);
			LCD_GLASS_WriteChar( tab+3,POINT_ON,COLUMN_OFF,2);

			WFE->CR1 = 0x0;
			CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_16);
			while (Wakeup_bool == FALSE);		

		}
	else
		wfi();
}

// Low Power RUN 
void mode3(void)
{
	int units=0, tens=0, hundreds=0, thousands=0;
  uint8_t tab[4];
	float LPR_Conso = 0;
	int LPR_Conso_nA = 0;
	int i = 0;
	int ADC_ConvResult;
	
	Wakeup_bool = FALSE;
	Function_bool = FALSE;
	LCD_GLASS_Clear();
	CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_16);
	LCD_GLASS_ScrollSentence(" LPRUN  ", 8,  SCROLL_NUM, SCROLL_SPEED_L);
	CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_1);
	LCD->CR3 = 0x0;
	while ((LCD->CR3 & 0x40) != 0x00);
	CLK_PeripheralClockConfig(CLK_Peripheral_LCD, DISABLE);
	
	GPIO_LowPower_Config(MCU_HALT);

	if (IDD_bool == FALSE)
		LPR_init();
	else
	{
		Vrefint = ADC_Supply();
		Vdd = 4095*1.23/Vrefint;

		ADC_Icc_Init();
		delay_ms(100);
		ADC_ConvResult = ADC_Icc_Test(MCU_LPR);

		LPR_Conso =  ((ADC_ConvResult *10 * Vdd) / 4.095)-OA_OFFSET;
		LPR_Conso_nA = (int)(LPR_Conso);
	
		
		convert_into_char(LPR_Conso_nA, tab);
		
		LCD_GLASS_Init();
		LCD_GLASS_Clear();
		LCD_GLASS_WriteChar( "A",POINT_OFF,COLUMN_OFF,7);
		LCD_GLASS_WriteChar( "u",POINT_OFF,COLUMN_OFF,6);
		LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,5);
		LCD_GLASS_WriteChar( tab+1,POINT_OFF,COLUMN_OFF,4);
		LCD_GLASS_WriteChar( tab+2,POINT_OFF,COLUMN_OFF,3);
		LCD_GLASS_WriteChar( tab+3,POINT_ON,COLUMN_OFF,2);
		CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_16);
		while (((EXTI->SR1)&0x02) == 0x0)
		Delay(60000);
		EXTI->SR1 = 0x02;
	}
	WFE->CR1=0x0;
	rim();
	LCD_GLASS_Init();
	Wakeup_bool = TRUE;
	Function_bool = FALSE;	
}

// Low Power Wait 
void mode4(void)
{
	float LPR_Conso = 0;
	int LPR_Conso_nA = 0;
  uint8_t tab[4];
	int ADC_ConvResult;
	float Vdd = 0;
	
	Wakeup_bool = FALSE;
	Function_bool = FALSE;
	LPWait_bool = TRUE;
	
	LCD_GLASS_Clear();
	CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_16);
	LCD_GLASS_ScrollSentence(" LPWAIT  ", 9,  SCROLL_NUM, SCROLL_SPEED_L);
	CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_1);
	
	LCD->CR3 = 0x0;
	while ((LCD->CR3 & 0x40) != 0x00);
	CLK_PeripheralClockConfig(CLK_Peripheral_LCD, DISABLE);
	GPIO_LowPower_Config(MCU_HALT);
	
	if (IDD_bool == FALSE)
		LPR_init();
	else
	{
		Vrefint = ADC_Supply();
		Vdd = 4095*1.23/Vrefint;

		ADC_Icc_Init();
		delay_ms(100);
		
		ADC_ConvResult = ADC_Icc_Test(MCU_LPR);
		
		LPR_Conso =  ((ADC_ConvResult *10 * Vdd) / 4.095)-OA_OFFSET;
		LPR_Conso_nA = (int)(LPR_Conso);
	
		
		convert_into_char(LPR_Conso_nA, tab);

		LCD_GLASS_Init();
		LCD_GLASS_Clear();
		LCD_GLASS_WriteChar( "A",POINT_OFF,COLUMN_OFF,7);
		LCD_GLASS_WriteChar( "u",POINT_OFF,COLUMN_OFF,6);
		LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,5);
		LCD_GLASS_WriteChar( tab+1,POINT_OFF,COLUMN_OFF,4);
		LCD_GLASS_WriteChar( tab+2,POINT_OFF,COLUMN_OFF,3);
		LCD_GLASS_WriteChar( tab+3,POINT_ON,COLUMN_OFF,2);
		CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_16);
		while (((EXTI->SR1)&0x02) == 0x0)
		Delay(60000);
		EXTI->SR1 = 0x02;
	}
	
	WFE->CR1=0x0;
	rim();
	LCD_GLASS_Init();
	Wakeup_bool = TRUE;
	Function_bool = FALSE;
	LPWait_bool = FALSE;
}

// Active Halt with LCD 
void mode5(void)
{
	float Halt_Conso = 0;
	int Halt_Conso_nA = 0;
  uint8_t tab[5];
	int ADC_ConvResult;
	float Vdd = 0;
	
	Wakeup_bool = FALSE;
	Function_bool = FALSE;
	LCD_GLASS_Clear();
	CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_16);
	LCD_GLASS_ScrollSentence("ACTHALT LCD  ", 13,  SCROLL_NUM, SCROLL_SPEED_L);
	CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_1);
	
	//PWR->CSR2=0x2;
	if (IDD_bool == FALSE)
	{
		a = RTC->TR1;
		b = RTC->TR2;
		c = RTC->TR3;
		d = RTC->DR3;
		RTC_secItEn();
		KeyPressed = FALSE;
	  while (KeyPressed == FALSE)
	  {
		  LCD_GLASS_WriteTime( a & 0xF     , 7, 0);
		  LCD_GLASS_WriteTime((a & 0xF0)>>4, 6, 1);
		  LCD_GLASS_WriteTime( b & 0xF     , 5, 0);
		  LCD_GLASS_WriteTime((b & 0xF0)>>4, 4, 1);
		  LCD_GLASS_WriteTime( c & 0xF     , 3, 0);
		  LCD_GLASS_WriteTime((c & 0xF0)>>4, 2, 0);

		  halt();
	  }
		RTC->CR2 = 0x0;
		Function_bool = FALSE;
		
	}
	else
	{
		Vrefint = ADC_Supply();
		Vdd = 4095*1.23/Vrefint;
	
		while (Function_bool == FALSE) 
		halt(); 
	
		Function_bool = FALSE;
		ADC_Icc_Init();
		delay_ms(100);

		ADC_ConvResult = ADC_Icc_Test(MCU_HALT_LCD);

		Halt_Conso =  ((ADC_ConvResult *10 * Vdd) / 4.095)-OA_OFFSET;
		Halt_Conso_nA = (int)(Halt_Conso);
		
		convert_into_char(Halt_Conso_nA, tab);

		LCD_GLASS_Init();
		LCD_GLASS_Clear();
		LCD_GLASS_WriteChar( "A",POINT_OFF,COLUMN_OFF,7);
		LCD_GLASS_WriteChar( "u",POINT_OFF,COLUMN_OFF,6);
		LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,5);
		LCD_GLASS_WriteChar( tab+1,POINT_OFF,COLUMN_OFF,4);
		LCD_GLASS_WriteChar( tab+2,POINT_OFF,COLUMN_OFF,3);
		LCD_GLASS_WriteChar( tab+3,POINT_ON,COLUMN_OFF,2);
		halt();
		CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_16);
	}
}

// Active Halt without LCD 
void mode6(void)
{
	float Halt_Conso = 0;
	int Halt_Conso_nA = 0;
  uint8_t tab[4];
	int ADC_ConvResult;
	float Vdd = 0;
	int i=0;
	
	Wakeup_bool = FALSE;
	Function_bool = FALSE;
	
	LCD_GLASS_Clear();
	CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_16);
	LCD_GLASS_ScrollSentence("ACTHALT  ", 9,  SCROLL_NUM, SCROLL_SPEED_L);
	CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_1);
	
	PWR->CSR2=0x2;
	LCD_PortMaskConfig(LCD_PortMaskRegister_0, 0x0);
	LCD_PortMaskConfig(LCD_PortMaskRegister_1, 0x0);
	LCD_PortMaskConfig(LCD_PortMaskRegister_2, 0x0);
	LCD_PortMaskConfig(LCD_PortMaskRegister_3, 0x0);
	LCD->CR3 = 0x0;
	while ((LCD->CR3 & 0x40) != 0x00);
	CLK_PeripheralClockConfig(CLK_Peripheral_LCD, DISABLE);
	PWR->CSR2=0x2;
	GPIO_LowPower_Config(MCU_HALT);
	if (IDD_bool == FALSE)
	{
		halt();
		PWR->CSR2=0x0;
		LCD_GLASS_Init();
	}
	else
	{

		Vrefint = ADC_Supply();
		Vdd = 4095*1.23/Vrefint;
		
		while (Function_bool == FALSE) 
		halt(); 	
		PWR->CSR2=0x0;
				
		Function_bool = FALSE;
		ADC_Icc_Init();
		delay_ms(100);
		ADC_ConvResult = ADC_Icc_Test(MCU_HALT);
		

		Halt_Conso =  ((ADC_ConvResult *10 * Vdd) / 4.095)-OA_OFFSET;
		Halt_Conso_nA = (int)(Halt_Conso);
		
		convert_into_char(Halt_Conso_nA, tab);
		
		LCD_GLASS_Init();
		LCD_GLASS_Clear();
		LCD_GLASS_WriteChar( "A",POINT_OFF,COLUMN_OFF,7);
		LCD_GLASS_WriteChar( "u",POINT_OFF,COLUMN_OFF,6);
		LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,5);
		LCD_GLASS_WriteChar( tab+1,POINT_OFF,COLUMN_OFF,4);
		LCD_GLASS_WriteChar( tab+2,POINT_OFF,COLUMN_OFF,3);
		LCD_GLASS_WriteChar( tab+3,POINT_ON,COLUMN_OFF,2);
		halt();
		while (Wakeup_bool == FALSE)
		CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_16);
	}
	
}

// HALT 
void mode7(void)
{
	float Halt_Conso = 0;
	int Halt_Conso_nA = 0;
  uint8_t tab[4];
	int ADC_ConvResult;
	float Vdd = 0;

	
	Wakeup_bool = FALSE;
	Function_bool = FALSE;
	
	LCD_GLASS_Clear();
	LCD_GLASS_DisplayString(" HALT ");
	
	Halt_Init();
	PWR->CSR2 = 0x2;
	
	if (IDD_bool == FALSE)
	{
		halt();
		PWR->CSR2 = 0x0;
		LCD_GLASS_Init();
	}
	else
	{

		Vrefint = ADC_Supply();
		Vdd = 4095*1.23/Vrefint;
	
	  while (Function_bool == FALSE) 
		halt();
		PWR->CSR2 = 0x0;
		
		Function_bool = FALSE;
		ADC_Icc_Init();
		delay_ms(100);
		ADC_ConvResult = ADC_Icc_Test(MCU_HALT);
		Halt_Conso =  ((ADC_ConvResult *10 * Vdd) / 4.095)-OA_OFFSET;
		Halt_Conso_nA = (int)(Halt_Conso);
		
		if ((Halt_Conso_nA < 800) && (Halt_Conso_nA > 200)) TEST_PASS = TRUE;
	
		
		convert_into_char(Halt_Conso_nA, tab);
		
		LCD_GLASS_Init();
		LCD_GLASS_Clear();
		LCD_GLASS_WriteChar( "A",POINT_OFF,COLUMN_OFF,7);
		LCD_GLASS_WriteChar( "u",POINT_OFF,COLUMN_OFF,6);
		LCD_GLASS_WriteChar( " ",POINT_OFF,COLUMN_OFF,5);
		LCD_GLASS_WriteChar( tab+1,POINT_OFF,COLUMN_OFF,4);
		LCD_GLASS_WriteChar( tab+2,POINT_OFF,COLUMN_OFF,3);
		LCD_GLASS_WriteChar( tab+3,POINT_ON,COLUMN_OFF,2);
		halt();
		while (Wakeup_bool == FALSE)
		CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_16);
	}
	
}
