
// Includes ------------------------------------------------------------------
#include "icc_measure.h"
#include "LPdemo_functions.h"


// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
#define SYS_CLK_HSI_DIV1
#define ICC_GPIO_PORT              GPIOA
#define ICC_CNTEN_GPIO_PIN         GPIO_Pin_2
#define ICC_WAKEUP_GPIO_PIN        GPIO_Pin_3
#define ICC_WAKEUP_EXTI_PIN        EXTI_Pin_3

extern bool mode_bool[NB_MODE];


/**
  * @brief  Inserts a delay time.
  * @param  nCount: specifies the delay time length.
  * @retval None
  */
void Delay(__IO uint16_t nCount)
{
  for(; nCount != 0; nCount--);
}

//------------------------------------------------------------------------------
// Function Name : delay_ms
// Description   : delay for some time in ms unit(partial accurate)
// Input         : n_ms is how many ms of time to delay
//------------------------------------------------------------------------------
void delay_ms(u16 n_ms)
{
	CLK_PeripheralClockConfig(CLK_Peripheral_TIM4, ENABLE);
  // Init TIMER 4 //
  // prescaler: / (2^6) = /64
  TIM4->PSCR = 6;
#ifdef SYS_CLK_HSE_DIV1
  // Auto-Reload value: 16M / 64 = 1/4M, 1/4M / 1k = 250
  TIM4->ARR = 250;
#else
#ifdef SYS_CLK_HSE_DIV2
  // Auto-Reload value: 16M/2 / 64 = 1/8M, 1/8M / 1k = 125
  TIM4->ARR = 125;
#else
#ifdef SYS_CLK_HSI_DIV1
  // Auto-Reload value: 16M / 64 = 1/4M, 1/4M / 1k = 250
  TIM4->ARR = 250;
#else
#ifdef SYS_CLK_HSI_DIV2
  // Auto-Reload value: 16M/2 / 64 = 1/8M, 1/8M / 1k = 125
  TIM4->ARR = 125;
#else
#error "either SYS_CLK_HSE_DIV1/DIV2 or SYS_CLK_HSI_DIV1/DIV2 should be defined"
#endif
#endif
#endif
#endif
  // Counter value: 2, to compensate the initialization of TIMER
  TIM4->CNTR = 2;

  // clear update flag
  TIM4->SR1 &= ~TIM4_SR1_UIF;
  // Enable Counter
  TIM4->CR1 |= TIM4_CR1_CEN;

  while(n_ms--)
  {
    while((TIM4->SR1 & TIM4_SR1_UIF) == 0) ;
    TIM4->SR1 &= ~TIM4_SR1_UIF;
  }

  // Disable Counter
  TIM4->CR1 &= ~TIM4_CR1_CEN;
}

//------------------------------------------------------------------------------
// Function Name : delay_10us
// Description   : delay for some time in 10us unit(partial accurate)
// Input         : n_10us is how many 10us of time to delay
//------------------------------------------------------------------------------
void delay_10us(u16 n_10us)
{
	CLK_PeripheralClockConfig(CLK_Peripheral_TIM4, ENABLE);
  // Init TIMER 4 //
  // prescaler: / (2^0) = /1
  TIM4->PSCR = 0;
#ifdef SYS_CLK_HSE_DIV1
  // Auto-Reload value: 16M / 1 = 16M, 16M / 100k = 160
  TIM4->ARR = 160;
#else
#ifdef SYS_CLK_HSE_DIV2
  // Auto-Reload value: 16M/2 / 1 = 8M, 8M / 100k = 80
  TIM4->ARR = 80;
#else
#ifdef SYS_CLK_HSI_DIV1
  // Auto-Reload value: 16M / 1 = 16M, 16M / 100k = 160
  TIM4->ARR = 160;
#else
#ifdef SYS_CLK_HSI_DIV2
  // Auto-Reload value: 16M/2 / 1 = 8M, 8M / 100k = 80
  TIM4->ARR = 80;
#else
#error "either SYS_CLK_HSE_DIV1/DIV2 or SYS_CLK_HSI_DIV1/DIV2 should be defined"
#endif
#endif
#endif
#endif
  // Counter value: 10, to compensate the initialization of TIMER
  TIM4->CNTR = 10;

  // clear update flag
  TIM4->SR1 &= ~TIM4_SR1_UIF;
  // Enable Counter
  TIM4->CR1 |= TIM4_CR1_CEN;

  while(n_10us--)
  {
    while((TIM4->SR1 & TIM4_SR1_UIF) == 0) ;
    TIM4->SR1 &= ~TIM4_SR1_UIF;
  }

  // Disable Counter
  TIM4->CR1 &= ~TIM4_CR1_CEN;
	CLK_PeripheralClockConfig(CLK_Peripheral_TIM4, DISABLE);

}
//-----------------------------------------------------------------
//   configure GPIOs before entering ActiveHalt mode
//-----------------------------------------------------------------
void GPIO_LowPower_Config(u8 config)
{
switch (config)
  {
  case MCU_HALT:
	  // Port A in output push-pull 0 except 
			//ICC wakeup pins input
			//ICC CNTEN output 1 inactive
		GPIO_Init(GPIOA, GPIO_Pin_0|GPIO_Pin_1| GPIO_Pin_4|GPIO_Pin_5|GPIO_Pin_6|GPIO_Pin_7, GPIO_Mode_Out_PP_Low_Slow);
		GPIO_Init(GPIOA, GPIO_Pin_2,GPIO_Mode_Out_PP_High_Slow);

		// Port B in output push-pull 0 
		GPIO_Init(GPIOB, GPIO_Pin_0|GPIO_Pin_1|GPIO_Pin_2|GPIO_Pin_3|GPIO_Pin_4|GPIO_Pin_5|GPIO_Pin_6|GPIO_Pin_7, GPIO_Mode_Out_PP_Low_Slow);
		// Port C in output push-pull 0 except Button pins
		#ifdef USE_LSE
			GPIO_Init(GPIOC, GPIO_Pin_2|GPIO_Pin_3|GPIO_Pin_4|GPIO_Pin_7, GPIO_Mode_Out_PP_Low_Slow);
		#else
			GPIO_Init(GPIOC, GPIO_Pin_2|GPIO_Pin_3|GPIO_Pin_4|GPIO_Pin_5|GPIO_Pin_6|GPIO_Pin_7, GPIO_Mode_Out_PP_Low_Slow);
		#endif
		// Port D in output push-pull 0 
		GPIO_Init(GPIOD, GPIO_Pin_0|GPIO_Pin_1|GPIO_Pin_2|GPIO_Pin_3|GPIO_Pin_4|GPIO_Pin_5|GPIO_Pin_6|GPIO_Pin_7, GPIO_Mode_Out_PP_Low_Slow);
		// Port E in output push-pull 0 
		GPIO_Init(GPIOE, GPIO_Pin_0|GPIO_Pin_1|GPIO_Pin_2|GPIO_Pin_3|GPIO_Pin_4|GPIO_Pin_5|GPIO_Pin_6|GPIO_Pin_7, GPIO_Mode_Out_PP_Low_Slow);
		// Port F in output push-pull 0
		GPIO_Init(GPIOF, GPIO_Pin_0|GPIO_Pin_1|GPIO_Pin_2|GPIO_Pin_3,GPIO_Mode_Out_PP_Low_Slow);

		break;
	}
}
//-----------------------------------------------------------------
// 	ADC_supply 
//-----------------------------------------------------------------
u16 ADC_Supply(void)
{
	u16 i, value[5], res;
  // initialize result
  res = 0;
	  // Enable ADC clock
  CLK_PeripheralClockConfig(CLK_Peripheral_ADC1, ENABLE);

  // de-initialize ADC
  ADC_DeInit(ADC1);
  // ADC configuration ---------------------------------------//
  // ADC configured as follow:
  //      - Channel VREF
  //      - Mode = Single ConversionMode(ContinuousConvMode disabled)
  //      - Resolution = 12Bit
  //      - Prescaler = /1
  // 	  	- sampling time 4
	ADC_VrefintCmd(ENABLE);
	delay_10us(3);
	

	ADC_Cmd(ADC1, ENABLE);	 
  ADC_Init(ADC1, ADC_ConversionMode_Single,
           ADC_Resolution_12Bit, ADC_Prescaler_1);

  ADC_SamplingTimeConfig(ADC1, ADC_Group_FastChannels, ADC_SamplingTime_9Cycles);
  ADC_ChannelCmd(ADC1, ADC_Channel_Vrefint, ENABLE);
	delay_10us(3);
  // Enable ADC1 

  // initialize result
  res = 0;
  for(i=4; i>0; i--)
  {
    // start ADC convertion by software
    ADC_SoftwareStartConv(ADC1);
    // wait until end-of-covertion
    while( ADC_GetFlagStatus(ADC1, ADC_FLAG_EOC) == 0 );
    // read ADC convertion result
    value[i] = ADC_GetConversionValue(ADC1);
    res += value[i];
  }
	// de-initialize ADC
	ADC_VrefintCmd(DISABLE);
  ADC_DeInit(ADC1);
	CLK_PeripheralClockConfig(CLK_Peripheral_ADC1, DISABLE);
  res >>= 2;
  return res;
}


//-----------------------------------------------------------------
//   ADC_Icc(ADC_24 of ADC_0~27) initialization
//-----------------------------------------------------------------
void ADC_Icc_Init(void)
{

	CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_1);
  // Enable ADC clock
  CLK_PeripheralClockConfig(CLK_Peripheral_ADC1, ENABLE);

  // de-initialize ADC
  ADC_DeInit(ADC1);
  // ADC configuration ---------------------------------------//
  // ADC configured as follow:
  //      - NbrOfChannel = 1 - ADC_Channel_24
  //      - Mode = Single ConversionMode(ContinuousConvMode disabled)
  //      - Resolution = 12Bit
  //      - Prescaler = /1
  // 	  - sampling time 159
	GPIO_Init(GPIOF, GPIO_Pin_0,GPIO_Mode_In_FL_No_IT);
	
  // Enable ADC1 
  ADC_Cmd(ADC1, ENABLE);
  ADC_Init(ADC1, ADC_ConversionMode_Single,
           ADC_Resolution_12Bit, ADC_Prescaler_1);

  ADC_SamplingTimeConfig(ADC1, ADC_Group_FastChannels, ADC_SamplingTime_192Cycles);
  ADC_ChannelCmd(ADC1, ADC_Channel_24, ENABLE);

  // disable SchmittTrigger for ADC_Channel_24, to save power
  ADC_SchmittTriggerConfig(ADC1, ADC_Channel_24, DISABLE);

  // a short time of delay is required after enable ADC
  delay_10us(3);
	
}
	
//-----------------------------------------------------------------
//   ADC_Icc(ADC_19 of ADC_0~27) test
//   3 MCU modes can be tested
//-----------------------------------------------------------------
u16 ADC_Icc_Test(u8 Mcu_State)
{
  u16 i, value[5], res;

  // initialize result
  res = 0;

  switch (Mcu_State)
  {
	
  case MCU_RUN:
	  ADC_DeInit(ADC1);
		ADC_SchmittTriggerConfig(ADC1, ADC_Channel_24, DISABLE);

		break;
		
 case MCU_LPR:
	  //PWR->CSR2 = 0x2;
    // de-initialize ADC - mandatory to get Halt/ActiveHalt current
    ADC_DeInit(ADC1);
		  // disable SchmittTrigger for ADC_Channel_24, to save power
    ADC_SchmittTriggerConfig(ADC1, ADC_Channel_24, DISABLE);
		CLK_PeripheralClockConfig(CLK_Peripheral_RTC, DISABLE);
		CLK_PeripheralClockConfig(CLK_Peripheral_LCD, DISABLE);
		#asm
			SIM
		#endasm
		WFE->CR1 = 0x80;
    
    GPIO_LowPower_Config(MCU_HALT);
		//EXTI_SetPinSensitivity(ICC_WAKEUP_EXTI_PIN, EXTI_Sensitivity_Rising); //BUG
		EXTI->CR1 = 0x40;
    // Config the EXTI to wake up from Halt Mode
		//GPIO_Init(ICC_GPIO_PORT, ICC_WAKEUP_GPIO_PIN, GPIO_Mode_In_FL_IT); 
		GPIOA->CR2 = 0x08;
// Activate CNT EN PIN as output push-pull, active low
		//GPIO_Init(ICC_GPIO_PORT, ICC_CNTEN_GPIO_PIN, GPIO_Mode_Out_PP_Low_Slow);
		//GPIOA->ODR = 0xFB;
		CLK_PeripheralClockConfig(CLK_Peripheral_ADC1, ENABLE);

   
	  delay_10us(1);
    
		LPR_init();
		EXTI->SR1 = 0x08; 

    break;
		
	case MCU_HALT_LCD:
    // de-initialize ADC - mandatory to get Halt/ActiveHalt current
		ADC_DeInit(ADC1);
		  // disable SchmittTrigger for ADC_Channel_24, to save power
    ADC_SchmittTriggerConfig(ADC1, ADC_Channel_24, DISABLE);
		//CLK_PeripheralClockConfig(CLK_Peripheral_RTC, DISABLE);
		//CLK_PeripheralClockConfig(CLK_Peripheral_LCD, DISABLE);
		#asm
			SIM
		#endasm
    
		if (mode_bool[5] == FALSE)
      GPIO_LowPower_Config(MCU_HALT);
		EXTI->CR1 = 0x40;
    // Config the EXTI to wake up from Halt Mode
		GPIOA->CR2 = 0x08;
// Activate CNT EN PIN as output push-pull, active low
		GPIOA->ODR = 0xFB;
		CLK_PeripheralClockConfig(CLK_Peripheral_ADC1, ENABLE);
   
	  delay_10us(1);
    
		#asm
			HALT
			SIM
		#endasm

    break;		
		
  case MCU_HALT:
	  PWR->CSR2 = 0x2;
    // de-initialize ADC - mandatory to get Halt/ActiveHalt current
		ADC_DeInit(ADC1);
		  // disable SchmittTrigger for ADC_Channel_24, to save power
    ADC_SchmittTriggerConfig(ADC1, ADC_Channel_24, DISABLE);
		//CLK_PeripheralClockConfig(CLK_Peripheral_RTC, DISABLE);
		//CLK_PeripheralClockConfig(CLK_Peripheral_LCD, DISABLE);
		#asm
			SIM
		#endasm
    
		if (mode_bool[5] == FALSE)
      GPIO_LowPower_Config(MCU_HALT);
		EXTI->CR1 = 0x40;
    // Config the EXTI to wake up from Halt Mode
		GPIOA->CR2 = 0x08;
// Activate CNT EN PIN as output push-pull, active low
		GPIOA->ODR = 0xFB;
		CLK_PeripheralClockConfig(CLK_Peripheral_ADC1, ENABLE);
   
	  delay_10us(1);
    
		#asm
			HALT
			SIM
		#endasm
		PWR->CSR2=0x0;

    break;

  }

  ADC_Icc_Init();
  // initialize result
	
  res = 0;
	
  for(i=4; i>0; i--)
  {
    // start ADC convertion by software
    ADC_SoftwareStartConv(ADC1);
    // wait until end-of-covertion
    while( ADC_GetFlagStatus(ADC1, ADC_FLAG_EOC) == 0 );
    // read ADC convertion result
    value[i] = ADC_GetConversionValue(ADC1);
    res += value[i];
  }
	
  // ICC_CNT_EN invalid (active LOW) 
	GPIOA->ODR = 0xFF;
	GPIOA->CR2 = 0x00;
	#asm
		RIM
	#endasm
	
	  // de-initialize ADC
  ADC_DeInit(ADC1);


	  // Disable ADC clock
  CLK_PeripheralClockConfig(CLK_Peripheral_ADC1, DISABLE);
	
	res >>= 2;
  return res;

}
	

