/**
  ******************************************************************************
  * @file    Project/Template/stm8l15x_it.c
  * @author  MCD Application Team
  * @version V0.0.3
  * @date    07/21/2009
  * @brief   Main Interrupt Service Routines.
  *          This file provides template for all peripherals interrupt service routine.
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2009 STMicroelectronics</center></h2>
  */ 

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"
#include "stm8l15x_it.h"
#include "stm8l15x_gpio.h"
// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
#define ICC_GPIO_PORT              GPIOA
#define ICC_CNTEN_GPIO_PIN         GPIO_Pin_2
// Private variables ---------------------------------------------------------
extern bool Function_bool;
extern bool Wakeup_bool;
extern bool KeyPressed;
// Private function prototypes -----------------------------------------------
// Private functions ---------------------------------------------------------
// Public functions ----------------------------------------------------------

 // @addtogroup IT_Functions
#ifdef _COSMIC_
/**
  * @brief Dummy interrupt routine
  * @par Parameters:
  * None
  * @retval 
  * None
*/
@far @interrupt void NonHandledInterrupt(void)
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
}
#endif

/**
  * @brief TRAP interrupt routine
  * @par Parameters:
  * None
  * @retval 
  * None
*/
#ifdef _COSMIC_
@far @interrupt void TRAP_IRQHandler(void)
#else /* _RAISONANCE_ */
void TRAP_IRQHandler(void) trap
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		while (1);
		return;
}
/**
  * @brief FLASH Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void FLASH_IRQHandler(void)
#else /* _RAISONANCE_ */
void FLASH_IRQHandler(void) interrupt 1
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		while (1);
		return;
}
/**
  * @brief DMA1 channel0 and channel1 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void DMA1_CHANNEL0_1_IRQHandler(void)
#else /* _RAISONANCE_ */
void DMA1_CHANNEL0_1_IRQHandler(void) interrupt 2
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		while (1);
		return;
}
/**
  * @brief DMA1 channel2 and channel3 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void DMA1_CHANNEL2_3_IRQHandler(void)
#else /* _RAISONANCE_ */
void DMA1_CHANNEL2_3_IRQHandler(void) interrupt 3
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		while (1);
		return;
}
/**
  * @brief RTC Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
extern	char a,b,c,d;
#ifdef _COSMIC_
@far @interrupt void RTC_IRQHandler(void)
#else /* _RAISONANCE_ */
void RTC_IRQHandler(void) interrupt 4
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
	if (((RTC->ISR2) & 0x1)==0x1)
	{
		RTC->ISR1 = 0x0;
		while ((RTC->ISR1 & 0x20) != 0x20);

    a = RTC->TR1;
    b = RTC->TR2;
		c = RTC->TR3;
		d = RTC->DR3;
		RTC->ISR1 = 0x0;
	  RTC->ISR2 = 0x0;
	}
	if (((RTC->ISR2) & 0x4)==0x4)
	{
		RTC->ISR1 = 0x0;
	  RTC->ISR2 = 0x0;
	}
		//while (1);
    return;
}
/**
  * @brief External IT PORTE/F and PVD Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void EXTIE_F_PVD_IRQHandler(void)
#else /* _RAISONANCE_ */
void EXTIE_F_PVD_IRQHandler(void) interrupt 5
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}

/**
  * @brief External IT PORTB Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void EXTIB_IRQHandler(void)
#else /* _RAISONANCE_ */
void EXTIB_IRQHandler(void) interrupt 6
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}

/**
  * @brief External IT PORTD Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void EXTID_IRQHandler(void)
#else /* _RAISONANCE_ */
void EXTID_IRQHandler(void) interrupt 7
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
			 
    */
		//while (1);
		return;
}

/**
  * @brief External IT PIN0 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void EXTI0_IRQHandler(void)
#else /* _RAISONANCE_ */
void EXTI0_IRQHandler(void) interrupt 8
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		Function_bool = TRUE;
		KeyPressed = TRUE;
		EXTI_ClearITPendingBit(EXTI_IT_Pin0);
		//while(1);
		return;
}

/**
  * @brief External IT PIN1 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void EXTI1_IRQHandler(void)
#else /* _RAISONANCE_ */
void EXTI1_IRQHandler(void) interrupt 9
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		Wakeup_bool = TRUE;
		KeyPressed = TRUE;
		EXTI_ClearITPendingBit(EXTI_IT_Pin1);
		//while(1);
		return;
}

/**
  * @brief External IT PIN2 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void EXTI2_IRQHandler(void)
#else /* _RAISONANCE_ */
void EXTI2_IRQHandler(void) interrupt 10
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		EXTI_ClearITPendingBit(EXTI_IT_Pin2);
		//while(1);
		return;
}

/**
  * @brief External IT PIN3 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void EXTI3_IRQHandler(void)
#else /* _RAISONANCE_ */
void EXTI3_IRQHandler(void) interrupt 11
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
//		EXTI_ClearITPendingBit(EXTI_IT_Pin3);
		EXTI->SR1 = 0x08;

//		GPIO_WriteBit(ICC_GPIO_PORT, ICC_CNTEN_GPIO_PIN, SET);
		return;
}

/**
  * @brief External IT PIN4 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void EXTI4_IRQHandler(void)
#else /* _RAISONANCE_ */
void EXTI4_IRQHandler(void) interrupt 12
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}

/**
  * @brief External IT PIN5 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void EXTI5_IRQHandler(void)
#else /* _RAISONANCE_ */
void EXTI5_IRQHandler(void) interrupt 13
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}

/**
  * @brief External IT PIN6 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void EXTI6_IRQHandler(void)
#else /* _RAISONANCE_ */
void EXTI6_IRQHandler(void) interrupt 14
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}

/**
  * @brief External IT PIN7 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void EXTI7_IRQHandler(void)
#else /* _RAISONANCE_ */
void EXTI7_IRQHandler(void) interrupt 15
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}
/**
  * @brief LCD start of new frame Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void LCD_IRQHandler(void)
#else /* _RAISONANCE_ */
void LCD_IRQHandler(void) interrupt 16
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}
/**
  * @brief CLK switch/CSS/TIM1 break Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void SWITCH_CSS_BREAK_DAC_IRQHandler(void)
#else /* _RAISONANCE_ */
void SWITCH_CSS_BREAK_DAC_IRQHandler(void) interrupt 17
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}

/**
  * @brief ADC1/Comparator Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void ADC1_COMP_IRQHandler(void)
#else /* _RAISONANCE_ */
void ADC1_COMP_IRQHandler(void) interrupt 18
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}

/**
  * @brief TIM2 Update/Overflow/Trigger/Break Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void TIM2_UPD_OVF_TRG_BRK_IRQHandler(void)
#else /* _RAISONANCE_ */
void TIM2_UPD_OVF_TRG_BRK_IRQHandler(void) interrupt 19
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}

/**
  * @brief Timer2 Capture/Compare Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void TIM2_CAP_IRQHandler(void)
#else /* _RAISONANCE_ */
void TIM2_CAP_IRQHandler(void) interrupt 20
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}


/**
  * @brief Timer3 Update/Overflow/Trigger/Break Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void TIM3_UPD_OVF_TRG_BRK_IRQHandler(void)
#else /* _RAISONANCE_ */
void TIM3_UPD_OVF_TRG_BRK_IRQHandler(void) interrupt 21
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}
/**
  * @brief Timer3 Capture/Compare Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void TIM3_CAP_IRQHandler(void)
#else /* _RAISONANCE_ */
void TIM3_CAP_IRQHandler(void) interrupt 22
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}
/**
  * @brief TIM1 Update/Overflow/Trigger/Commutation Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void TIM1_UPD_OVF_TRG_COM_IRQHandler(void)
#else /* _RAISONANCE_ */
void TIM1_UPD_OVF_TRG_COM_IRQHandler(void) interrupt 23
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}
/**
  * @brief TIM1 Capture/Compare Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void TIM1_CAP_IRQHandler(void)
#else /* _RAISONANCE_ */
void TIM1_CAP_IRQHandler(void) interrupt 24
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}

/**
  * @brief TIM4 Update/Overflow/Trigger Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void TIM4_UPD_OVF_TRG_IRQHandler(void)
#else /* _RAISONANCE_ */
void TIM4_UPD_OVF_TRG_IRQHandler(void) interrupt 25
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}
/**
  * @brief SPI1 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void SPI1_IRQHandler(void)
#else /* _RAISONANCE_ */
void SPI1_IRQHandler(void) interrupt 26
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */	
		//while (1);
		return;		
}

/**
  * @brief USART1 TX Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void USART1_TX_IRQHandler(void)
#else /* _RAISONANCE_ */
void USART1_TX_IRQHandler(void) interrupt 27
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}

/**
  * @brief USART1 RX Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void USART1_RX_IRQHandler(void)
#else /* _RAISONANCE_ */
void USART1_RX_IRQHandler(void) interrupt 28
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}

/**
  * @brief I2C1 Interrupt routine.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
#ifdef _COSMIC_
@far @interrupt void I2C1_IRQHandler(void)
#else /* _RAISONANCE_ */
void I2C1_IRQHandler(void) interrupt 29
#endif /* _COSMIC_ */
{
    /* In order to detect unexpected events during development,
       it is recommended to set a breakpoint on the following instruction.
    */
		//while (1);
		return;
}


