/**
  ******************************************************************************
  * @file    stm8l_eval.h
  * @author  MCD Application Team
  * @version V0.0.3
  * @date    07/21/2009
  * @brief   Header file for stm8l_eval.c module.
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2009 STMicroelectronics</center></h2>
  */ 
  
// Define to prevent recursive inclusion -------------------------------------
#ifndef __STM8L_EVAL_H
#define __STM8L_EVAL_H

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"

 // @addtogroup Utilities
  
 // @addtogroup STM8L_EVAL


 // @defgroup STM8L_EVAL_Exported_Types
  
 // @defgroup STM8L_EVAL_Exported_Constants

/** 
  * @brief  Uncomment the line corresponding to the STMicroelectronics evaluation
  *   board used in your application.
  *   
  *  Tip: To avoid modifying this file each time you need to switch between these
  *       boards, you can define the board in your toolchain compiler preprocessor.    
  */ 
#if !defined (USE_STM8L1526_EVAL) 
  #define USE_STM8L1526_EVAL
#endif

#ifdef USE_STM8L1526_EVAL
 #include "stm8l1526_eval.h"
#else 
 #error "Please select first the STM8L15X_EVAL board to be used (in stm8l_eval.h)"
#endif


typedef enum 
{
  LED1 = 0,
  LED2 = 1,
  LED3 = 2,
  LED4 = 3,
	LED8 = 4  /* Bicolor Led */
} Led_TypeDef;

typedef enum 
{  
  Button_KEY = 0,
  Button_RIGHT = 1,
  Button_LEFT = 2,
  Button_UP = 3,
  Button_DOWN = 4,
  Button_SEL = 5
} Button_TypeDef;

typedef enum 
{  
  Mode_GPIO = 0,
  Mode_EXTI = 1
} Button_Mode_TypeDef;

typedef enum 
{ 
  JOY_NONE = 0,
  JOY_CENTER = 1,
  JOY_DOWN = 2,
  JOY_LEFT = 3,
  JOY_RIGHT = 4,
  JOY_UP = 5
} JOY_State_TypeDef;

typedef enum 
{
  COM1 = 0
} COM_TypeDef;
 

 // @defgroup STM8L_EVAL_Exported_Macros

 // @defgroup STM8L_EVAL_Exported_Functions
void STM_EVAL_LEDInit(Led_TypeDef Led);
void STM_EVAL_LEDOn(Led_TypeDef Led);
void STM_EVAL_LEDOff(Led_TypeDef Led);
void STM_EVAL_LEDToggle(Led_TypeDef Led);
void STM_EVAL_PBInit(Button_TypeDef Button, Button_Mode_TypeDef Button_Mode);
uint8_t STM_EVAL_PBGetState(Button_TypeDef Button);
void STM_EVAL_COMInit(COM_TypeDef COM, uint32_t USART_BaudRate, 
                                       USART_WordLength_TypeDef USART_WordLength, 
																			 USART_StopBits_TypeDef USART_StopBits,
								                       USART_Parity_TypeDef USART_Parity, 
																			 USART_Mode_TypeDef USART_Mode);

#endif /* __STM8L_EVAL_H */



  

